@@ -26,7 +26,7 @@ T = TypeVar("T")
 def mchoose(
     items: List[T],
     checked: bool = True,
-    title: str = "Please select one"
+    title: str = "Please choose among the options"
 ) -> Optional[List[T]]:
     """
     TODO
