@@ -13,21 +13,23 @@
    Copyright 2022, HSPyLib team
 """
 
+from typing import Optional
+
+from hspylib.modules.cli.vt100.vt_utils import restore_cursor
+
 from clitt.core.tui.menu.tui_menu import ON_TRIGGER_CB, TUIMenu
 from clitt.core.tui.menu.tui_menu_ui import TUIMenuUi
-from clitt.core.tui.menu.tui_menu_utils import TUIMenuUtils
-from hspylib.modules.cli.vt100.vt_utils import restore_cursor
-from typing import Optional
 
 
 class TUIMenuAction(TUIMenu):
-    """TODO"""
+    """Represent a menu item action. Each action trigger a callback function.
+    """
 
     def execute(self) -> Optional[TUIMenu]:
         self._render()
         ret_menu = self._on_trigger(self._parent)
         if not ret_menu:
-            TUIMenuUtils.wait_keystroke()
+            TUIMenu.wait_keystroke()
         return ret_menu if ret_menu else self._default_trigger_cb(self)
 
     def _render(self) -> None:
@@ -46,5 +48,6 @@ class TUIMenuAction(TUIMenu):
         self._on_trigger: ON_TRIGGER_CB = on_trigger or super()._default_trigger_cb
 
     def on_trigger(self, cb_on_trigger: ON_TRIGGER_CB) -> None:
-        """TODO"""
+        """Setter for the on_trigger callback. It is called when a menu item is triggered.
+        """
         self._on_trigger = cb_on_trigger
